==> mktcenter-service-1.0.2-vg-20220525.073555-2-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskAwardBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.bizvane.mktcenterservice.models.po.MktCouponInviteePO;
import com.bizvane.mktcenterservice.models.po.MktCouponPO;
import com.bizvane.mktcenterservice.models.po.MktTaskPOWithBLOBs;

import java.math.BigDecimal;
import java.util.List;

/**
 * @Author: lijunwei
 * @Time: 2018/8/7 16:49
 * 消费奖励相关的判断Bo
 */
public class TaskAwardBO extends MktTaskPOWithBLOBs {
    //消费任务
    private Long mktTaskOrderId;
    //任务条件/订单来源限制：0全部类型，1线下订单，2微商城订单
    private Integer orderSource;
    //金额
    private BigDecimal consumeAmount;
    //次数
    private Integer consumeTimes;

    //邀请开卡任务Id
    private Long mktTaskInviteId;
    //邀请开卡人数
    private Integer inviteNum;
    //1.单条件奖励 2.循环奖励
    private Integer rewardType;
    //最大邀请成功人数限制
    private Integer maxInviteNum;

    //完善资料任务id
    private Long mktTaskProfileId;
    //完善资料的字段code
    private String propertyCode;

    //分享任务id
    private Long mktTaskShareId;
    //分享任务类型
    private Integer shareUrlType;
    //分享人任务的次数
    private Integer shareTimes;
    //分享内容
    private String shareUrl;

    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;
    //门店限制类型：1黑名单，2白名单
    private Integer storeLimitType;
    //白名单店铺list
    private String storeLimitList;

    private Integer mbrConditionType;

    private String mbrCondition;

    //券奖励
    private List<MktCouponPO> mktCouponPOList;

    //受邀人券奖励
    private List<MktCouponInviteePO> mktCouponInviteePOList;

    /**
     * 受邀人成功开卡奖励开关 1=开启;0=关闭
     */
    private Boolean newMemberAward;

    /**
     * 受邀人成功开卡赠送积分数值
     */
    private Integer newMemberPoints;

    /**
     * 问卷调查模板code
     */
    private String templatecode;

    /**
     * 非会员问卷调查模板code
     */
    private String touristTemplateCode;

    /**
     * 是否需要校验适用条件
     */
    private Boolean needCheckCondition;


    public Long getMktTaskOrderId() {
        return mktTaskOrderId;
    }

    public void setMktTaskOrderId(Long mktTaskOrderId) {
        this.mktTaskOrderId = mktTaskOrderId;
    }

    public Integer getOrderSource() {
        return orderSource;
    }

    public void setOrderSource(Integer orderSource) {
        this.orderSource = orderSource;
    }

    public BigDecimal getConsumeAmount() {
        return consumeAmount;
    }

    public void setConsumeAmount(BigDecimal consumeAmount) {
        this.consumeAmount = consumeAmount;
    }

    public Integer getConsumeTimes() {
        return consumeTimes;
    }

    public void setConsumeTimes(Integer consumeTimes) {
        this.consumeTimes = consumeTimes;
    }

    public List<MktCouponPO> getMktCouponPOList() {
        return mktCouponPOList;
    }

    public void setMktCouponPOList(List<MktCouponPO> mktCouponPOList) {
        this.mktCouponPOList = mktCouponPOList;
    }

    public Long getMktTaskInviteId() {
        return mktTaskInviteId;
    }

    public void setMktTaskInviteId(Long mktTaskInviteId) {
        this.mktTaskInviteId = mktTaskInviteId;
    }

    public Integer getInviteNum() {
        return inviteNum;
    }

    public void setInviteNum(Integer inviteNum) {
        this.inviteNum = inviteNum;
    }

    public Long getMktTaskProfileId() {
        return mktTaskProfileId;
    }

    public void setMktTaskProfileId(Long mktTaskProfileId) {
        this.mktTaskProfileId = mktTaskProfileId;
    }

    public String getPropertyCode() {
        return propertyCode;
    }

    public void setPropertyCode(String propertyCode) {
        this.propertyCode = propertyCode;
    }

    public Long getMktTaskShareId() {
        return mktTaskShareId;
    }

    public void setMktTaskShareId(Long mktTaskShareId) {
        this.mktTaskShareId = mktTaskShareId;
    }

    public Integer getShareUrlType() {
        return shareUrlType;
    }

    public void setShareUrlType(Integer shareUrlType) {
        this.shareUrlType = shareUrlType;
    }

    public Integer getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(Integer shareTimes) {
        this.shareTimes = shareTimes;
    }

    public String getShareUrl() {
        return shareUrl;
    }

    public void setShareUrl(String shareUrl) {
        this.shareUrl = shareUrl;
    }

    public Boolean getIsStoreLimit() {
        return isStoreLimit;
    }

    public void setIsStoreLimit(Boolean isStoreLimit) {
        this.isStoreLimit = isStoreLimit;
    }

    public Integer getStoreLimitType() {
        return storeLimitType;
    }

    public void setStoreLimitType(Integer storeLimitType) {
        this.storeLimitType = storeLimitType;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }

    @Override
    public Integer getMbrConditionType() {
        return mbrConditionType;
    }

    @Override
    public void setMbrConditionType(Integer mbrConditionType) {
        this.mbrConditionType = mbrConditionType;
    }

    @Override
    public String getMbrCondition() {
        return mbrCondition;
    }

    @Override
    public void setMbrCondition(String mbrCondition) {
        this.mbrCondition = mbrCondition;
    }

    public Integer getRewardType() {
        return rewardType;
    }

    public void setRewardType(Integer rewardType) {
        this.rewardType = rewardType;
    }

    public Integer getMaxInviteNum() {
        return maxInviteNum;
    }

    public void setMaxInviteNum(Integer maxInviteNum) {
        this.maxInviteNum = maxInviteNum;
    }

    public List<MktCouponInviteePO> getMktCouponInviteePOList() {
        return mktCouponInviteePOList;
    }

    public void setMktCouponInviteePOList(List<MktCouponInviteePO> mktCouponInviteePOList) {
        this.mktCouponInviteePOList = mktCouponInviteePOList;
    }

    public Boolean getNewMemberAward() {
        return newMemberAward;
    }

    public void setNewMemberAward(Boolean newMemberAward) {
        this.newMemberAward = newMemberAward;
    }

    public Integer getNewMemberPoints() {
        return newMemberPoints;
    }

    public void setNewMemberPoints(Integer newMemberPoints) {
        this.newMemberPoints = newMemberPoints;
    }

    public String getTemplatecode() {
        return templatecode;
    }

    public void setTemplatecode(String templatecode) {
        this.templatecode = templatecode;
    }

    public String getTouristTemplateCode() {
        return touristTemplateCode;
    }

    public void setTouristTemplateCode(String touristTemplateCode) {
        this.touristTemplateCode = touristTemplateCode;
    }

    public Boolean getNeedCheckCondition() {
        return needCheckCondition;
    }

    public void setNeedCheckCondition(Boolean needCheckCondition) {
        this.needCheckCondition = needCheckCondition;
    }
}

==> mktcenter-service-1.5.0-vg-20220622.073709-4-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskAwardBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.bizvane.mktcenterservice.models.po.MktCouponInviteePO;
import com.bizvane.mktcenterservice.models.po.MktCouponPO;
import com.bizvane.mktcenterservice.models.po.MktTaskPOWithBLOBs;

import java.math.BigDecimal;
import java.util.List;

/**
 * @Author: lijunwei
 * @Time: 2018/8/7 16:49
 * 消费奖励相关的判断Bo
 */
public class TaskAwardBO extends MktTaskPOWithBLOBs {
    //消费任务
    private Long mktTaskOrderId;
    //任务条件/订单来源限制：0全部类型，1线下订单，2微商城订单
    private Integer orderSource;
    //金额
    private BigDecimal consumeAmount;
    //次数
    private Integer consumeTimes;

    //邀请开卡任务Id
    private Long mktTaskInviteId;
    //邀请开卡人数
    private Integer inviteNum;
    //1.单条件奖励 2.循环奖励
    private Integer rewardType;
    //最大邀请成功人数限制
    private Integer maxInviteNum;

    //完善资料任务id
    private Long mktTaskProfileId;
    //完善资料的字段code
    private String propertyCode;

    //分享任务id
    private Long mktTaskShareId;
    //分享任务类型
    private Integer shareUrlType;
    //分享人任务的次数
    private Integer shareTimes;
    //分享内容
    private String shareUrl;

    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;
    //门店限制类型：1黑名单，2白名单
    private Integer storeLimitType;
    //白名单店铺list
    private String storeLimitList;

    private Integer mbrConditionType;

    private String mbrCondition;

    //券奖励
    private List<MktCouponPO> mktCouponPOList;

    //受邀人券奖励
    private List<MktCouponInviteePO> mktCouponInviteePOList;

    /**
     * 受邀人成功开卡奖励开关 1=开启;0=关闭
     */
    private Boolean newMemberAward;

    /**
     * 受邀人成功开卡赠送积分数值
     */
    private Integer newMemberPoints;

    /**
     * 问卷调查模板code
     */
    private String templateCode;

    /**
     * 非会员问卷调查模板code
     */
    private String touristTemplateCode;

    /**
     * 是否需要校验适用条件
     */
    private Boolean needCheckCondition;


    public Long getMktTaskOrderId() {
        return mktTaskOrderId;
    }

    public void setMktTaskOrderId(Long mktTaskOrderId) {
        this.mktTaskOrderId = mktTaskOrderId;
    }

    public Integer getOrderSource() {
        return orderSource;
    }

    public void setOrderSource(Integer orderSource) {
        this.orderSource = orderSource;
    }

    public BigDecimal getConsumeAmount() {
        return consumeAmount;
    }

    public void setConsumeAmount(BigDecimal consumeAmount) {
        this.consumeAmount = consumeAmount;
    }

    public Integer getConsumeTimes() {
        return consumeTimes;
    }

    public void setConsumeTimes(Integer consumeTimes) {
        this.consumeTimes = consumeTimes;
    }

    public List<MktCouponPO> getMktCouponPOList() {
        return mktCouponPOList;
    }

    public void setMktCouponPOList(List<MktCouponPO> mktCouponPOList) {
        this.mktCouponPOList = mktCouponPOList;
    }

    public Long getMktTaskInviteId() {
        return mktTaskInviteId;
    }

    public void setMktTaskInviteId(Long mktTaskInviteId) {
        this.mktTaskInviteId = mktTaskInviteId;
    }

    public Integer getInviteNum() {
        return inviteNum;
    }

    public void setInviteNum(Integer inviteNum) {
        this.inviteNum = inviteNum;
    }

    public Long getMktTaskProfileId() {
        return mktTaskProfileId;
    }

    public void setMktTaskProfileId(Long mktTaskProfileId) {
        this.mktTaskProfileId = mktTaskProfileId;
    }

    public String getPropertyCode() {
        return propertyCode;
    }

    public void setPropertyCode(String propertyCode) {
        this.propertyCode = propertyCode;
    }

    public Long getMktTaskShareId() {
        return mktTaskShareId;
    }

    public void setMktTaskShareId(Long mktTaskShareId) {
        this.mktTaskShareId = mktTaskShareId;
    }

    public Integer getShareUrlType() {
        return shareUrlType;
    }

    public void setShareUrlType(Integer shareUrlType) {
        this.shareUrlType = shareUrlType;
    }

    public Integer getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(Integer shareTimes) {
        this.shareTimes = shareTimes;
    }

    public String getShareUrl() {
        return shareUrl;
    }

    public void setShareUrl(String shareUrl) {
        this.shareUrl = shareUrl;
    }

    public Boolean getIsStoreLimit() {
        return isStoreLimit;
    }

    public void setIsStoreLimit(Boolean isStoreLimit) {
        this.isStoreLimit = isStoreLimit;
    }

    public Integer getStoreLimitType() {
        return storeLimitType;
    }

    public void setStoreLimitType(Integer storeLimitType) {
        this.storeLimitType = storeLimitType;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }

    @Override
    public Integer getMbrConditionType() {
        return mbrConditionType;
    }

    @Override
    public void setMbrConditionType(Integer mbrConditionType) {
        this.mbrConditionType = mbrConditionType;
    }

    @Override
    public String getMbrCondition() {
        return mbrCondition;
    }

    @Override
    public void setMbrCondition(String mbrCondition) {
        this.mbrCondition = mbrCondition;
    }

    public Integer getRewardType() {
        return rewardType;
    }

    public void setRewardType(Integer rewardType) {
        this.rewardType = rewardType;
    }

    public Integer getMaxInviteNum() {
        return maxInviteNum;
    }

    public void setMaxInviteNum(Integer maxInviteNum) {
        this.maxInviteNum = maxInviteNum;
    }

    public List<MktCouponInviteePO> getMktCouponInviteePOList() {
        return mktCouponInviteePOList;
    }

    public void setMktCouponInviteePOList(List<MktCouponInviteePO> mktCouponInviteePOList) {
        this.mktCouponInviteePOList = mktCouponInviteePOList;
    }

    public Boolean getNewMemberAward() {
        return newMemberAward;
    }

    public void setNewMemberAward(Boolean newMemberAward) {
        this.newMemberAward = newMemberAward;
    }

    public Integer getNewMemberPoints() {
        return newMemberPoints;
    }

    public void setNewMemberPoints(Integer newMemberPoints) {
        this.newMemberPoints = newMemberPoints;
    }

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public String getTouristTemplateCode() {
        return touristTemplateCode;
    }

    public void setTouristTemplateCode(String touristTemplateCode) {
        this.touristTemplateCode = touristTemplateCode;
    }

    public Boolean getNeedCheckCondition() {
        return needCheckCondition;
    }

    public void setNeedCheckCondition(Boolean needCheckCondition) {
        this.needCheckCondition = needCheckCondition;
    }
}
